@@ -1,12 +1,12 @@
 from dopt.optimizers import *
 from dopt.trainer import Trainer
-from dopt.utils import processCommandsInParallel
+from dopt.server import Server
 
-__version__ = "0.0.2.12"
+__version__ = "0.0.3"
 
 __all__ = [
     "Trainer",
     "Optimizer",
     "NEIOptimizer",
-    "processCommandsInParallel"
+    "Server"
 ]
